@@ -11,7 +11,9 @@ echo
 echo "Updating bash codes..."
 
 esc_MAINPATH=${ROTT_ETCDIR//\//\\/}
-sed -e 's/^MAINPATH=.*/MAINPATH=\"$esc_MAINPATH\"/' rottlog >newrottlog
+esc_STATPATH=${ROTT_STATPATH//\//\\/}
+sed -e 's/^MAINPATH=.*/MAINPATH=\"$esc_MAINPATH\"/' \
+    -e 's/^STATPATH=.*/STATPATH=\"$esc_STATPATH\"/' rottlog >newrottlog
 if [ ! -s newrottlog ]; then
   echo "Error using sed to modify rottlog!!"
   echo "Please send to stefko5@inwind.it an e-mail with as much as possible"
@@ -49,5 +51,13 @@ for D in $DOCFILES; do
 done
 
 mkdir -p $ROTT_ETCDIR
-chmod 0300 $ROTT_ETCDIR
+chmod $ETC_MODE $ROTT_ETCDIR
+
+mkdir -p $ROTT_STATPATH
+chmod $STAT_MODE $ROTT_STATPATH
+
+echo "Installation finished. Now Rot[t]Log can be used in command line mode"
+echo "or using crontab."
+echo "If there are some bug please send me an e-mail explaining to me problems"
+echo "at address: stefko5@inwind.it"
 
